Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(64)

Unified Diff: client/crashpad_client_mac.cc

Issue 1305893010: Don’t trigger EXC_CORPSE_NOTIFY on OS X 10.11 (Closed) Base URL: https://chromium.googlesource.com/crashpad/crashpad@master
Patch Set: Address review feedback Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | client/simulate_crash_mac_test.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: client/crashpad_client_mac.cc
diff --git a/client/crashpad_client_mac.cc b/client/crashpad_client_mac.cc
index c81dd543057d70b3ea007cd58e9cbea13b67901d..02067c9b73085dd4f4043b5737701b5b0e8c5528 100644
--- a/client/crashpad_client_mac.cc
+++ b/client/crashpad_client_mac.cc
@@ -207,13 +207,11 @@ bool CrashpadClient::UseHandler() {
//
// EXC_MASK_RESOURCE and EXC_MASK_GUARD are not available on all systems, and
// the kernel will reject attempts to use them if it does not understand them,
// so AND them with ExcMaskAll(). EXC_MASK_CRASH is not present in
// ExcMaskAll() but is always supported. See the documentation for
// ExcMaskAll().
ExceptionPorts exception_ports(ExceptionPorts::kTargetTypeTask, TASK_NULL);
if (!exception_ports.SetExceptionPort(
- EXC_MASK_CRASH |
- ((EXC_MASK_RESOURCE | EXC_MASK_GUARD) & ExcMaskAll()),
+ (EXC_MASK_CRASH | EXC_MASK_RESOURCE | EXC_MASK_GUARD) &
+ ExcMaskValid(),
exception_port_,
EXCEPTION_STATE_IDENTITY | MACH_EXCEPTION_CODES,
MACHINE_THREAD_STATE)) {
@@ -207,13 +207,11 @@ bool CrashpadClient::UseHandler() {
// EXC_MASK_RESOURCE and EXC_MASK_GUARD are not available on all systems, and
// the kernel will reject attempts to use them if it does not understand them,
- // so AND them with ExcMaskAll(). EXC_MASK_CRASH is not present in
- // ExcMaskAll() but is always supported. See the documentation for
- // ExcMaskAll().
+ // so AND them with ExcMaskValid(). EXC_MASK_CRASH is always supported.
ExceptionPorts exception_ports(ExceptionPorts::kTargetTypeTask, TASK_NULL);
if (!exception_ports.SetExceptionPort(
« no previous file with comments | « no previous file | client/simulate_crash_mac_test.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698